@@ -12,7 +12,6 @@ sub new {
     bless $self, $class; # Bless into this class
 
     $class->make_accessor("title");
-    $class->make_accessor("year");
     $class->make_accessor("publisher");
 
     if(exists $options{xmlref}) {
@@ -30,9 +29,6 @@ sub init_via_xmlref {
     $self->authors($xmlref->{Authors}->{Author});
     $self->title($xmlref->{ProductName});
     $self->publisher($xmlref->{Manufacturer});
-
-    my ($year) = ($xmlref->{ReleaseDate} =~ /(\d{4})/);
-    $self->year($year);
 }
 
 ##################################################
@@ -119,10 +115,6 @@ Returns the book's publishing company as a string.
 
 Returns the book's title as a string.
 
-=item year()
-
-Returns the year extracted from C<ReleaseDate()>.
-
 =item new(xmlref => $xmlref)
 
 Initializes an object by passing a hash of hashes structure containing
@@ -133,7 +125,7 @@ data.
 =back
 
 Check out L<Net::Amazon::Property> for all-purpose accessors, like
-C<OurPrice>, C<ListPrice>, etc.
+C<year>, C<OurPrice>, C<ListPrice>, etc.
 
 =head1 SEE ALSO
 
